/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *   Johnny Stenback <jst@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsIDOMDocument.idl"

/**
 * The nsIDOMHTMLDocument interface is the interface to a [X]HTML
 * document object.
 *
 * This interface is trying to follow the DOM Level 2 HTML specification:
 * http://www.w3.org/TR/DOM-Level-2-HTML/
 *
 * with changes from the work-in-progress WHATWG HTML specification:
 * http://www.whatwg.org/specs/web-apps/current-work/
 */

[scriptable, uuid(0d3bef04-a890-4dbc-8571-b8e96ff5426b)]
interface nsIDOMHTMLDocument : nsIDOMDocument
{
           attribute DOMString            title;
  readonly attribute DOMString            referrer;
  // domain is readonly per spec, but it's settable in
  // nsIDOMNSHTMLDocument
  [noscript] readonly attribute DOMString domain;
  readonly attribute DOMString            URL;
           attribute nsIDOMHTMLElement    body;
  readonly attribute nsIDOMHTMLCollection images;
  readonly attribute nsIDOMHTMLCollection applets;
  readonly attribute nsIDOMHTMLCollection links;
  readonly attribute nsIDOMHTMLCollection forms;
  readonly attribute nsIDOMHTMLCollection anchors;
           attribute DOMString            cookie;
                                             // raises(DOMException) on setting

  // open() is noscript here since the DOM Level 0 version of open()
  // returned nsIDOMDocument, and not void. The script version of
  // open() is defined in nsIDOMNSHTMLDocument.
  [noscript] void           open();
  void                      close();

  void                      write([optional, Null(Stringify)] in DOMString text);
  void                      writeln([optional, Null(Stringify)] in DOMString text);

  nsIDOMNodeList            getElementsByName(in DOMString elementName);
};
